##  Collection Structure
Collections are organized in a hierarchical structure:
  * Collection group: A container that holds multiple collections. Collection groups appear on the left-side panel as expandable sections.
  * Collection: The main organizational unit where dashboards, reports, and diagrams are grouped. Collections appear on the left-side panel within collection groups.
  * Subcollection: A further subdivision within a collection. Subcollections do not display on the left-side panel. When a collection is selected, subcollections appear as folders within that collection's page. In the user interface, subcollections are referred to as collections.
